summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser_list.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/browser_list.cc
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/browser_list.cc')
-rw-r--r--chrome/browser/browser_list.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/browser_list.cc b/chrome/browser/browser_list.cc
index c1676c0..3b6ee8b 100644
--- a/chrome/browser/browser_list.cc
+++ b/chrome/browser/browser_list.cc
@@ -18,7 +18,7 @@
#if defined(OS_WIN)
// TODO(port): these can probably all go away, even on win
#include "chrome/browser/profile.h"
-#include "chrome/browser/tab_contents/web_contents.h"
+#include "chrome/browser/tab_contents/tab_contents.h"
#endif
@@ -289,20 +289,20 @@ void BrowserList::RemoveBrowserFrom(Browser* browser, list_type* browser_list) {
browser_list->erase(remove_browser);
}
-WebContentsIterator::WebContentsIterator()
+TabContentsIterator::TabContentsIterator()
: browser_iterator_(BrowserList::begin()),
web_view_index_(-1),
cur_(NULL) {
Advance();
}
-void WebContentsIterator::Advance() {
+void TabContentsIterator::Advance() {
// Unless we're at the beginning (index = -1) or end (iterator = end()),
// then the current WebContents should be valid.
DCHECK(web_view_index_ || browser_iterator_ == BrowserList::end() ||
cur_) << "Trying to advance past the end";
// Update cur_ to the next WebContents in the list.
for (;;) {
web_view_index_++;
@@ -316,8 +316,8 @@ void WebContentsIterator::Advance() {
}
}
- WebContents* next_tab =
- (*browser_iterator_)->GetTabContentsAt(web_view_index_)->AsWebContents();
+ TabContents* next_tab =
+ (*browser_iterator_)->GetTabContentsAt(web_view_index_);
if (next_tab) {
cur_ = next_tab;
return;
@@ -289,20 +289,20 @@ void BrowserList::RemoveBrowserFrom(Browser* browser, list_type* browser_list) {
// Unless we're at the beginning (index = -1) or end (iterator = end()),
- // then the current WebContents should be valid.
+ // then the current TabContents should be valid.
DCHECK(web_view_index_ || browser_iterator_ == BrowserList::end() ||
cur_) << "Trying to advance past the end";
@@ -289,20 +289,20 @@ void BrowserList::RemoveBrowserFrom(Browser* browser, list_type* browser_list) {
DCHECK(web_view_index_ || browser_iterator_ == BrowserList::end() ||
cur_) << "Trying to advance past the end";
- // Update cur_ to the next WebContents in the list.
+ // Update cur_ to the next TabContents in the list.
for (;;) {
web_view_index_++;